GpuColorWrite class

Color write mask bits.

See WebGPU spec: GPUColorWrite.

Constructors

GpuColorWrite()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const int
Write all channels.
alpha → const int
Write the alpha channel.
blue → const int
Write the blue channel.
green → const int
Write the green channel.
red → const int
Write the red channel.