GpuCompareFunction enum

Comparison function for depth/stencil tests and samplers.

See WebGPU spec: GPUCompareFunction.

Inheritance
Available extensions

Values

never → const GpuCompareFunction

Test never passes.

less → const GpuCompareFunction

Passes if new value < current value.

equal → const GpuCompareFunction

Passes if new value == current value.

lessEqual → const GpuCompareFunction

Passes if new value <= current value.

greater → const GpuCompareFunction

Passes if new value > current value.

notEqual → const GpuCompareFunction

Passes if new value != current value.

greaterEqual → const GpuCompareFunction

Passes if new value >= current value.

always → const GpuCompareFunction

Test always passes.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GpuCompareFunction>
A constant List of the values in this enum, in order of their declaration.