GpuTextureUsage class abstract

Texture usage flag constants.

See WebGPU spec: GPUTextureUsage.

Constructors

GpuTextureUsage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

copyDst → const GpuTextureUsageFlags
Texture can be used as a copy destination.
copySrc → const GpuTextureUsageFlags
Texture can be used as a copy source.
renderAttachment → const GpuTextureUsageFlags
Texture can be used as a color or depth/stencil attachment.
storageBinding → const GpuTextureUsageFlags
Texture can be bound as a storage texture in a shader.
textureBinding → const GpuTextureUsageFlags
Texture can be bound as a sampled texture in a shader.
transientAttachment → const GpuTextureUsageFlags
Texture may be allocated lazily (tile-based GPUs).