storageBinding constant
GpuTextureUsageFlags
const storageBinding
Texture can be bound as a storage texture in a shader.
Implementation
static const storageBinding = GpuTextureUsageFlags(0x08);
Texture can be bound as a storage texture in a shader.
static const storageBinding = GpuTextureUsageFlags(0x08);