WgpuCommandBuffer class

A recorded command buffer ready for submission.

Implemented types

Constructors

WgpuCommandBuffer.internal(int _handle, {String label = ''})

Properties

handle int
Native handle. Use with care.
no setter
hashCode int
The hash code for this object.
no setterinherited
label String
A human-readable label for debugging.
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited