A GPU adapter — represents a physical GPU.
Properties
-
features
→ Set<
GpuFeatureName> -
Features supported by this adapter.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → GpuAdapterInfo
-
Information about this adapter.
no setter
- limits → GpuLimits
-
Hardware limits for this adapter.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestDevice(
[GpuDeviceDescriptor descriptor = const GpuDeviceDescriptor()]) → Future< GpuDevice> - Request a device from this adapter.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited