A compute pass encoder for recording compute dispatch commands.
- Implemented types
- Available extensions
Properties
Methods
-
dispatchWorkgroups(
int x, [int y = 1, int z = 1]) → void - Dispatches workgroups.
-
dispatchWorkgroupsIndirect(
GpuBuffer buffer, {int offset = 0}) → void - Dispatches workgroups using parameters from a buffer.
-
end(
) → void - Ends the compute pass.
-
insertDebugMarker(
String label) → void - Inserts a debug marker into the command stream.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popDebugGroup(
) → void - Ends the current debug group.
-
pushDebugGroup(
String label) → void - Begins a named debug group.
-
setBindGroup(
int index, GpuBindGroup bindGroup, {List< int> ? dynamicOffsets}) → void - Binds a bind group at the given index.
-
setImmediates(
int offset, TypedData data) → void -
Available on GpuComputePassEncoder, provided by the WgpuComputePassImmediates extension
Sets immediate (push constant) data on the compute pass. -
setPipeline(
GpuComputePipeline pipeline) → void - Sets the current compute pipeline.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited