GpuFeatureName enum
GPU feature names.
Values
- coreFeaturesAndLimits → const GpuFeatureName
-
Baseline features and limits for all devices.
- depthClipControl → const GpuFeatureName
-
Allows
unclippedDepthin primitive state. - depth32FloatStencil8 → const GpuFeatureName
-
Enables the
depth32float-stencil8texture format. - textureCompressionBc → const GpuFeatureName
-
Enables BC compressed texture formats.
- textureCompressionBcSliced3d → const GpuFeatureName
-
Enables BC compressed textures with 3D slicing.
- textureCompressionEtc2 → const GpuFeatureName
-
Enables ETC2 compressed texture formats.
- textureCompressionAstc → const GpuFeatureName
-
Enables ASTC compressed texture formats.
- textureCompressionAstcSliced3d → const GpuFeatureName
-
Enables ASTC compressed textures with 3D slicing.
- timestampQuery → const GpuFeatureName
-
Enables timestamp queries on compute and render passes.
- indirectFirstInstance → const GpuFeatureName
-
Allows non-zero
firstInstancein indirect draw calls. - shaderF16 → const GpuFeatureName
-
Enables
f16type in WGSL shaders. - rg11b10UfloatRenderable → const GpuFeatureName
-
Allows RG11B10UFloat format as a render target.
- bgra8UnormStorage → const GpuFeatureName
-
Allows BGRA8Unorm format as a storage texture.
- float32Filterable → const GpuFeatureName
-
Allows float32 texture formats to be filtered.
- float32Blendable → const GpuFeatureName
-
Allows float32 texture formats to be blended.
- clipDistances → const GpuFeatureName
-
Enables
clip_distancesbuiltin in WGSL. - dualSourceBlending → const GpuFeatureName
-
Enables dual-source blending (src1, oneMinusSrc1, etc.).
- subgroups → const GpuFeatureName
-
Enables subgroup operations in shaders.
- textureFormatsTier1 → const GpuFeatureName
-
Enables tier 1 extended texture formats (16-bit normalized, etc.).
- textureFormatsTier2 → const GpuFeatureName
-
Enables tier 2 extended texture formats (16-bit normalized on more types).
- primitiveIndex → const GpuFeatureName
-
Enables
primitive_indexbuiltin in WGSL fragment shaders. - textureComponentSwizzle → const GpuFeatureName
-
Enables texture component swizzle on texture views.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GpuFeatureName> - A constant List of the values in this enum, in order of their declaration.