Command queue for submitting GPU work.
- Implemented types
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onSubmittedWorkDone(
) → Future< void> - Returns a Future that resolves when all previously submitted work is done.
-
submit(
List< GpuCommandBuffer> commandBuffers) → void - Submits command buffers for execution.
-
toString(
) → String -
A string representation of this object.
inherited
-
writeBuffer(
GpuBuffer buffer, Uint8List data, {int bufferOffset = 0, int dataOffset = 0, int? size}) → void - Writes data to a buffer.
-
writeTexture(
{required GpuTexture texture, required Uint8List data, required int bytesPerRow, required int width, int height = 1, int depthOrArrayLayers = 1, int mipLevel = 0, GpuTextureAspect aspect = GpuTextureAspect.all, int originX = 0, int originY = 0, int originZ = 0, int dataOffset = 0, int? rowsPerImage}) → void - Writes data to a texture.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited