GpuRenderPipelineDescriptor class
Render pipeline descriptor.
Constructors
-
GpuRenderPipelineDescriptor({String label = '', required GpuPipelineLayout? layout, required GpuShaderModule vertexModule, String? vertexEntryPoint, Map<
String, double> vertexConstants = const {}, List<GpuVertexBufferLayout?> vertexBuffers = const [], GpuShaderModule? fragmentModule, String? fragmentEntryPoint, Map<String, double> fragmentConstants = const {}, List<GpuColorTargetState?> colorTargets = const [], GpuPrimitiveTopology primitiveTopology = GpuPrimitiveTopology.triangleList, GpuIndexFormat? stripIndexFormat, GpuFrontFace frontFace = GpuFrontFace.ccw, GpuCullMode cullMode = GpuCullMode.none, bool unclippedDepth = false, GpuDepthStencilState? depthStencil, int multisampleCount = 1, int multisampleMask = 0xFFFFFFFF, bool alphaToCoverageEnabled = false}) -
Creates a render pipeline descriptor.
const
Properties
- alphaToCoverageEnabled → bool
-
Whether alpha-to-coverage is enabled.
final
-
colorTargets
→ List<
GpuColorTargetState?> -
Color targets for the fragment stage. Null elements disable that slot.
final
- cullMode → GpuCullMode
-
Face culling mode.
final
- depthStencil → GpuDepthStencilState?
-
Depth/stencil state, or null to disable.
final
-
fragmentConstants
→ Map<
String, double> -
Pipeline-overridable constants for the fragment stage.
final
- fragmentEntryPoint → String?
-
Fragment shader entry point name, or null for default.
final
- fragmentModule → GpuShaderModule?
-
Shader module containing the fragment entry point, or null.
final
- frontFace → GpuFrontFace
-
Front face winding order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Debug label.
final
- layout → GpuPipelineLayout?
-
Pipeline layout, or null for auto layout.
final
- multisampleCount → int
-
Number of samples per pixel for multisampling.
final
- multisampleMask → int
-
Bitmask controlling which samples are active.
final
- primitiveTopology → GpuPrimitiveTopology
-
Primitive topology.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stripIndexFormat → GpuIndexFormat?
-
Index format for strip topologies, or null for list topologies.
final
- unclippedDepth → bool
-
Whether depth clipping is disabled. Requires "depth-clip-control".
final
-
vertexBuffers
→ List<
GpuVertexBufferLayout?> -
Vertex buffer layouts. Null elements are gaps in the slot numbering.
final
-
vertexConstants
→ Map<
String, double> -
Pipeline-overridable constants for the vertex stage.
final
- vertexEntryPoint → String?
-
Vertex shader entry point name, or null for default.
final
- vertexModule → GpuShaderModule
-
Shader module containing the vertex entry point.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited