GpuStencilFaceState class
Stencil face state.
Constructors
- GpuStencilFaceState({GpuCompareFunction compare = GpuCompareFunction.always, GpuStencilOperation failOp = GpuStencilOperation.keep, GpuStencilOperation depthFailOp = GpuStencilOperation.keep, GpuStencilOperation passOp = GpuStencilOperation.keep})
-
Creates a stencil face state with defaults that always pass and keep.
const
Properties
- compare → GpuCompareFunction
-
Comparison function for the stencil test.
final
- depthFailOp → GpuStencilOperation
-
Operation when the stencil test passes but depth fails.
final
- failOp → GpuStencilOperation
-
Operation when the stencil test fails.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passOp → GpuStencilOperation
-
Operation when both stencil and depth tests pass.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited